@@ -7,7 +7,7 @@ RDF::Trine::Parser - RDF Parser class
 
 =head1 VERSION
 
-This document describes RDF::Trine::Parser version 1.001
+This document describes RDF::Trine::Parser version 1.003
 
 =head1 SYNOPSIS
 
@@ -53,7 +53,7 @@ our %format_uris;
 our %encodings;
 
 BEGIN {
-	$VERSION	= '1.001';
+	$VERSION	= '1.003';
 	can_load( modules => {
 		'Data::UUID'	=> undef,
 		'UUID::Tiny'	=> undef,
@@ -223,52 +223,59 @@ sub parse_url_into_model {
 	if (defined $args{canonicalize}) {
 		$options{ canonicalize }	= $args{canonicalize};
 	}
-	if ($url =~ /[.](x?rdf|owl)$/ or $content =~ m/\x{FEFF}?<[?]xml /smo) {
-		my $parser	= RDF::Trine::Parser::RDFXML->new(%options);
-		$parser->parse_into_model( $url, $content, $model, %args );
-		return 1;
-	} elsif ($url =~ /[.]ttl$/ or $content =~ m/@(prefix|base)/smo) {
-		my $parser	= RDF::Trine::Parser::Turtle->new(%options);
-		my $data	= decode('utf8', $content);
-		$parser->parse_into_model( $url, $data, $model, %args );
-		return 1;
-	} elsif ($url =~ /[.]trig$/) {
-		my $parser	= RDF::Trine::Parser::Trig->new(%options);
-		my $data	= decode('utf8', $content);
-		$parser->parse_into_model( $url, $data, $model, %args );
-		return 1;
-	} elsif ($url =~ /[.]nt$/) {
-		my $parser	= RDF::Trine::Parser::NTriples->new(%options);
-		$parser->parse_into_model( $url, $content, $model, %args );
-		return 1;
-	} elsif ($url =~ /[.]nq$/) {
-		my $parser	= RDF::Trine::Parser::NQuads->new(%options);
-		$parser->parse_into_model( $url, $content, $model, %args );
-		return 1;
-	} elsif ($url =~ /[.]js(?:on)?$/) {
-		my $parser	= RDF::Trine::Parser::RDFJSON->new(%options);
-		$parser->parse_into_model( $url, $content, $model, %args );
-		return 1;
-	} elsif ($url =~ /[.]x?html?$/) {
-		my $parser	= RDF::Trine::Parser::RDFa->new(%options);
-		$parser->parse_into_model( $url, $content, $model, %args );
-		return 1;
-	} else {
-		my @types	= keys %{ { map { $_ => 1 } values %media_types } };
-		foreach my $pclass (@types) {
-			my $data	= $content;
-			if (my $e = $encodings{ $pclass }) {
-				$data	= decode( $e, $content );
+	
+	my $ok	= 0;
+	try {
+		if ($url =~ /[.](x?rdf|owl)$/ or $content =~ m/\x{FEFF}?<[?]xml /smo) {
+			my $parser	= RDF::Trine::Parser::RDFXML->new(%options);
+			$parser->parse_into_model( $url, $content, $model, %args );
+			$ok	= 1;;
+		} elsif ($url =~ /[.]ttl$/ or $content =~ m/@(prefix|base)/smo) {
+			my $parser	= RDF::Trine::Parser::Turtle->new(%options);
+			my $data	= decode('utf8', $content);
+			$parser->parse_into_model( $url, $data, $model, %args );
+			$ok	= 1;;
+		} elsif ($url =~ /[.]trig$/) {
+			my $parser	= RDF::Trine::Parser::Trig->new(%options);
+			my $data	= decode('utf8', $content);
+			$parser->parse_into_model( $url, $data, $model, %args );
+			$ok	= 1;;
+		} elsif ($url =~ /[.]nt$/) {
+			my $parser	= RDF::Trine::Parser::NTriples->new(%options);
+			$parser->parse_into_model( $url, $content, $model, %args );
+			$ok	= 1;;
+		} elsif ($url =~ /[.]nq$/) {
+			my $parser	= RDF::Trine::Parser::NQuads->new(%options);
+			$parser->parse_into_model( $url, $content, $model, %args );
+			$ok	= 1;;
+		} elsif ($url =~ /[.]js(?:on)?$/) {
+			my $parser	= RDF::Trine::Parser::RDFJSON->new(%options);
+			$parser->parse_into_model( $url, $content, $model, %args );
+			$ok	= 1;;
+		} elsif ($url =~ /[.]x?html?$/) {
+			my $parser	= RDF::Trine::Parser::RDFa->new(%options);
+			$parser->parse_into_model( $url, $content, $model, %args );
+			$ok	= 1;;
+		} else {
+			my @types	= keys %{ { map { $_ => 1 } values %media_types } };
+			foreach my $pclass (@types) {
+				my $data	= $content;
+				if (my $e = $encodings{ $pclass }) {
+					$data	= decode( $e, $content );
+				}
+				my $parser	= $pclass->new(%options);
+				my $ok		= 0;
+				try {
+					$parser->parse_into_model( $url, $data, $model, %args );
+					$ok	= 1;
+				} catch RDF::Trine::Error::ParserError with {};
+				last if ($ok);
 			}
-			my $parser	= $pclass->new(%options);
-			my $ok		= 0;
-			try {
-				$parser->parse_into_model( $url, $data, $model, %args );
-				$ok	= 1;
-			} catch RDF::Trine::Error::ParserError with {};
-			return 1 if ($ok);
 		}
-	}
+	} catch RDF::Trine::Error with {
+		my $e	= shift;
+	};
+	return 1 if ($ok);
 	throw RDF::Trine::Error::ParserError -text => "Failed to parse data from $url";
 }
 
